@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document::OpenAPI;
 # ABSTRACT: One OpenAPI v3.1 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.057';
+our $VERSION = '0.058';
 
 use 5.020;
 use Moo;
@@ -239,7 +239,7 @@ sub _add_vocab_and_default_schemas ($self) {
   $js->add_format_validation(int32 => +{
     type => 'number',
     sub => sub ($x) {
-      require Math::BigInt;
+      require Math::BigInt; Math::BigInt->VERSION(1.999701);
       $x = Math::BigInt->new($x);
       return if $x->is_nan;
       my $bound = Math::BigInt->new(2) ** 31;
@@ -250,7 +250,7 @@ sub _add_vocab_and_default_schemas ($self) {
   $js->add_format_validation(int64 => +{
     type => 'number',
     sub => sub ($x) {
-      require Math::BigInt;
+      require Math::BigInt; Math::BigInt->VERSION(1.999701);
       $x = Math::BigInt->new($x);
       return if $x->is_nan;
       my $bound = Math::BigInt->new(2) ** 63;
@@ -315,7 +315,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 SYNOPSIS
 
